@@ -151,7 +151,9 @@ class SourceCode:  # noqa: R090
         """
         typing_start_line = len(self.header) + len(self.imports)
 
-        if re.match(r"^if TYPE_CHECKING:$", source_lines[typing_start_line]):
+        if len(source_lines) > 0 and re.match(
+            r"^if TYPE_CHECKING:$", source_lines[typing_start_line]
+        ):
             self.typing.append(source_lines[typing_start_line])
             typing_start_line += 1
             for line in source_lines[typing_start_line:]:
@@ -300,7 +302,13 @@ class SourceCode:  # noqa: R090
             import_string: String required to import the package.
         """
         # Find the package name
-        project_package = os.path.basename(here()).replace("-", "_")
+        try:
+            project_package = os.path.basename(here()).replace("-", "_")
+        except RecursionError:  # pragma: no cover
+            # I don't know how to make a test that raises this error :(
+            # To manually reproduce, follow the steps of
+            # https://github.com/lyz-code/autoimport/issues/131
+            return None
         package_objects = extract_package_objects(project_package)
 
         # nocover: as the tests are run inside the autoimport virtualenv, it will
